<?php

namespace Drupal\decoupled_kit\Controller;

use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
use Drupal\Core\Url;
use Symfony\Component\HttpFoundation\Request;

/**
 * Class DecoupledHelperController.
 */
class DecoupledHelperController extends ControllerBase {

  /**
   * Check request path.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   User request.
   * @param bool $needCanonicalUrl
   *   Need call canonicalPath().
   *
   * @return string
   *   Checked path or exception if empty.
   */
  public function checkPath(Request $request, $needCanonicalUrl = TRUE) {
    $path = $request->query->get('path');
    if (empty($path)) {
      throw new NotFoundHttpException('Unable to work with empty path. Please send a ?path query string parameter with your request.');
    }

    if ($needCanonicalUrl) {
      $path = $this->canonicalPath($path);
    }
    return $path;
  }

  /**
   * Canonical path.
   *
   * @param string $path
   *   Input path.
   * @param bool $url_path_only
   *   Only path part of url.
   *
   * @return string
   *   Canonical path.
   */
  public function canonicalPath($path, $url_path_only = TRUE) {
    $path = mb_strtolower(trim($path));
    if ($url_path_only) {
      $path = parse_url($path, PHP_URL_PATH);
    }
    return sprintf('/%s', ltrim($path, '/'));
  }

  /**
   * Get entity from path.
   *
   * @param string $path
   *   Path.
   *
   * @return object|bool
   *   Entity object or null
   */
  public function getEntityFromPath($path) {
    if (empty($path)) {
      return NULL;
    }

    try {
      $params = Url::fromUri("internal:" . $path)->getRouteParameters();
    }
    catch (\Exception $e) {
      return NULL;
    }
    $entity_type = key($params);
    if (empty($entity_type)) {
      return NULL;
    }

    $id = $params[$entity_type];
    $entity = $this->entityTypeManager()->getStorage($entity_type)->load($id);
    return $entity;
  }

}
